==> haskell-pandoc-types-1.23.1-138-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-types
version:              1.23.1
visibility:           public
id:                   pandoc-types-1.23.1-7gWDUsUafgnGN4MZXQBBdX
key:                  pandoc-types-1.23.1-7gWDUsUafgnGN4MZXQBBdX
license:              BSD-3-Clause
copyright:            (c) 2006-2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  4d66c35d1871d3860c588cf6a61083b3
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-types-1.23.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-types-1.23.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-types-1.23.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-types
hs-libraries:         HSpandoc-types-1.23.1-7gWDUsUafgnGN4MZXQBBdX
depends:
    QuickCheck-2.15.0.1-2pZpRuW8a4m1OLZKRhi2a3
    aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4 base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0 ghc-prim-0.9.1
    syb-0.7.3-JxKwJKAj8VO69Skm5xz2vL text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-types-1.23.1-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pandoc-types
version:              1.23.1
visibility:           public
id:                   pandoc-types-1.23.1-JjlVk8mHzRf1JYJLiI61nl
key:                  pandoc-types-1.23.1-JjlVk8mHzRf1JYJLiI61nl
license:              BSD-3-Clause
copyright:            (c) 2006-2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://pandoc.org/
synopsis:             Types for representing a structured document
description:
    @Text.Pandoc.Definition@ defines the '\''Pandoc'\'' data
    structure, which is used by pandoc to represent
    structured documents.  This module used to live
    in the pandoc package, but starting with pandoc 1.7, it
    has been split off, so that other packages can use it
    without drawing in all of pandoc'\''s dependencies, and
    pandoc itself can depend on packages (like citeproc-hs)
    that use them.

    @Text.Pandoc.Builder@ provides functions for building
    up @Pandoc@ structures programmatically.

    @Text.Pandoc.Generic@ provides generic functions for
    manipulating Pandoc documents.

    @Text.Pandoc.Walk@ provides faster, nongeneric functions
    for manipulating Pandoc documents.

    @Text.Pandoc.JSON@ provides functions for serializing
    and deserializing a @Pandoc@ structure to and from JSON.

category:             Text
abi:                  a521148da1a43ea8e642fae8314eaa02
exposed:              True
exposed-modules:
    Text.Pandoc.Arbitrary Text.Pandoc.Builder Text.Pandoc.Definition
    Text.Pandoc.Generic Text.Pandoc.JSON Text.Pandoc.Walk

hidden-modules:       Paths_pandoc_types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pandoc-types-1.23.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pandoc-types-1.23.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pandoc-types-1.23.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-types
hs-libraries:         HSpandoc-types-1.23.1-JjlVk8mHzRf1JYJLiI61nl
depends:
    QuickCheck-2.15.0.1-Ev8f4YvWcjR3aGAT6KgUIz
    aeson-2.1.2.1-IUt8ms8F4mK1p5ihNOaPfT base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0 ghc-prim-0.9.1
    syb-0.7.3-7hkxsEejTxP3yJx3PgFbmA text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-types/html/pandoc-types.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
